.. _pathloss_step:

===================
Pathloss Correction
===================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.pathloss
